#!/bin/bash

echo "----> Installing Tick Stack"
# Define tickstack software versions
INFLUX_VERSION=1.5.2
INFLUX_CHECKSUM=42fede7b497bdf30d4eb5138db218d1add986fca4fce4a8bcd9c7d6dabaf572a

KAPACITOR_VERSION=1.4.1
KAPACITOR_CHECKSUM=eea9b215f241906570eafe3857e1d4c5

CHRONOGRAF_VERSION=1.4.4.2
CHRONOGRAF_CHECKSUM=eea6915aa6db8f134fcd3b095e863b773bfb3a16a26e346dd65904a07df97963

# install virtualenvwrapper to manage python environments - and check
apt-get update
echo "----> Installing Python3 and Pip3"
apt-get install -y python3 python3-pip wget curl
update-alternatives --install /usr/bin/python python /usr/bin/python3 10

echo "----> Installing virtualenv and wrapper"
apt-get install -y python3-virtualenv virtualenvwrapper
pip3 install virtualenv
pip3 install virtualenvwrapper

# install influx
echo "----> Installing InfluxDB"
wget https://dl.influxdata.com/influxdb/releases/influxdb_${INFLUX_VERSION}_amd64.deb 2> /dev/null
sha256sum influxdb_${INFLUX_VERSION}_amd64.deb | grep $INFLUX_CHECKSUM > /dev/null
if [ $? == 1 ]; then
	echo "influx download failed checksum"
	exit 1
fi
dpkg -i influxdb_${INFLUX_VERSION}_amd64.deb

# install kapacitor
echo "----> Installing Kapacitor"
wget https://dl.influxdata.com/kapacitor/releases/kapacitor_${KAPACITOR_VERSION}_amd64.deb 2> /dev/null
md5sum kapacitor_${KAPACITOR_VERSION}_amd64.deb | grep $KAPACITOR_CHECKSUM > /dev/null
if [ $? == 1 ]; then
	echo "Kapacitor download failed checksum"
	exit 1
fi
dpkg -i kapacitor_${KAPACITOR_VERSION}_amd64.deb

# install Chronograf
echo "----> Installing Chronograph"
wget https://dl.influxdata.com/chronograf/releases/chronograf_${CHRONOGRAF_VERSION}_amd64.deb 2> /dev/null
sha256sum chronograf_${CHRONOGRAF_VERSION}_amd64.deb | grep $CHRONOGRAF_CHECKSUM > /dev/null
if [ $? == 1 ]; then
	echo "Chronograf download failed checksum"
	exit 1
fi
dpkg -i chronograf_${CHRONOGRAF_VERSION}_amd64.deb

systemctl start influxdb
systemctl start kapacitor
systemctl start chronograf

